@@ -12,26 +12,47 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+import re
 import os
 
 
+def slugify(message):
+    message = re.sub(r"[^\w\s]", '', message)
+    message = re.sub(r"\s+", '-', message)
+
+    return message
+
+
+def unslugify(message):
+    message = message.replace(".", ". ")
+    message = message.replace("-", " ")
+    message = " ".join(word.capitalize() for word in message.split())
+    return message
+
+
 def context(app, message=None):
     def toc():
         result = []
         for entry in os.listdir(app.config['BLOGROOT']):
-            if os.path.isfile(entry) and not entry.startswith("."):
-                result.append("* [{article}](../{article})".format(
+            if os.path.isfile(entry) and not entry.startswith(".") and \
+               entry not in app.config['TOC_BLACKLIST']:
+                result.append("* [{unslug}](../{article})".format(
+                    unslug=unslugify(entry),
                     article=entry))
-        return "\n".join(result)
+        return "\n".join(sorted(result))
 
     context_dict = {
         "author": app.config['AUTHOR'],
         "description": app.config['DESCRIPTION'],
         "lang": app.config['DEFAULT_LANG'],
+        "navbar_links": app.config['NAVBAR_LINKS'],
+        "static_dir": app.config['STATIC_DIR'],
         "title": app.config['BLOGTITLE'],
         "toc": toc()
     }
     if message:
         context_dict['text'] = message['content']
         context_dict.update(message['metadata'])
+    if app.config.get("FAVICON"):
+        context_dict["favicon"] = app.config["FAVICON"]
     return context_dict
